@@ -9,7 +9,7 @@ def Connection(config: Config):
     repository = Repository(config=config)
     try:
         yield repository
-        repository.commit()
+        # repository.commit()
     except Exception as e:
         Log.error(f'Error while running database operation: {e}')
         repository.rollback()
